BUNDLE_NAME = "openconfig"

CAPABILITIES = {
    "cisco-xr-openconfig-interfaces-types": "2016-10-12",
    "openconfig-bgp": "2016-06-21",
    "openconfig-bgp-common": "2016-06-21",
    "openconfig-bgp-common-multiprotocol": "2016-06-21",
    "openconfig-bgp-common-structure": "2016-06-21",
    "openconfig-bgp-global": "2016-06-21",
    "openconfig-bgp-neighbor": "2016-06-21",
    "openconfig-bgp-peer-group": "2016-06-21",
    "openconfig-bgp-policy": "2016-06-21",
    "openconfig-bgp-types": "2016-06-21",
    "openconfig-channel-monitor": "2017-07-08",
    "openconfig-extensions": "2015-10-09",
    "openconfig-if-aggregate": "2016-05-26",
    "openconfig-if-ethernet": "2016-05-26",
    "openconfig-if-ip": "2016-05-26",
    "openconfig-interfaces": "2016-05-26",
    "openconfig-lacp": "2016-05-26",
    "openconfig-local-routing": "2016-05-11",
    "openconfig-mpls": "2015-11-05",
    "openconfig-mpls-igp": "2015-11-05",
    "openconfig-mpls-ldp": "2015-11-05",
    "openconfig-mpls-rsvp": "2015-11-05",
    "openconfig-mpls-sr": "2015-11-05",
    "openconfig-mpls-static": "2015-11-05",
    "openconfig-mpls-te": "2015-11-05",
    "openconfig-mpls-types": "2015-11-05",
    "openconfig-optical-amplifier": "2017-07-08",
    "openconfig-platform": "2016-06-06",
    "openconfig-platform-transceiver": "2016-05-24",
    "openconfig-platform-types": "2016-06-06",
    "openconfig-policy-types": "2016-05-12",
    "openconfig-rib-bgp": "2016-04-11",
    "openconfig-rib-bgp-types": "2016-04-11",
    "openconfig-routing-policy": "2016-05-12",
    "openconfig-telemetry": "2016-02-04",
    "openconfig-terminal-device": "2016-06-17",
    "openconfig-transport-line-common": "2017-07-08",
    "openconfig-transport-line-protection": "2017-03-28",
    "openconfig-transport-types": "2016-06-17",
    "openconfig-types": "2017-01-13",
    "openconfig-vlan": "2016-05-26",
    "openconfig-vlan-types": "2016-05-26",
}

ENTITY_LOOKUP = {
    ("http://openconfig.net/yang/bgp", "bgp"): "openconfig_bgp.Bgp",
    ("openconfig-bgp", "bgp"): "openconfig_bgp.Bgp",
    ("http://openconfig.net/yang/channel-monitor", "channel-monitors"): "openconfig_channel_monitor.ChannelMonitors",
    ("openconfig-channel-monitor", "channel-monitors"): "openconfig_channel_monitor.ChannelMonitors",
    ("http://openconfig.net/yang/interfaces", "interfaces"): "openconfig_interfaces.Interfaces",
    ("openconfig-interfaces", "interfaces"): "openconfig_interfaces.Interfaces",
    ("http://openconfig.net/yang/lacp", "lacp"): "openconfig_lacp.Lacp",
    ("openconfig-lacp", "lacp"): "openconfig_lacp.Lacp",
    ("http://openconfig.net/yang/local-routing", "local-routes"): "openconfig_local_routing.LocalRoutes",
    ("openconfig-local-routing", "local-routes"): "openconfig_local_routing.LocalRoutes",
    ("http://openconfig.net/yang/mpls", "mpls"): "openconfig_mpls.Mpls",
    ("openconfig-mpls", "mpls"): "openconfig_mpls.Mpls",
    ("http://openconfig.net/yang/optical-amplfier", "optical-amplifier"): "openconfig_optical_amplifier.OpticalAmplifier",
    ("openconfig-optical-amplifier", "optical-amplifier"): "openconfig_optical_amplifier.OpticalAmplifier",
    ("http://openconfig.net/yang/platform", "components"): "openconfig_platform.Components",
    ("openconfig-platform", "components"): "openconfig_platform.Components",
    ("http://openconfig.net/yang/rib/bgp", "bgp-rib"): "openconfig_rib_bgp.BgpRib",
    ("openconfig-rib-bgp", "bgp-rib"): "openconfig_rib_bgp.BgpRib",
    ("http://openconfig.net/yang/routing-policy", "routing-policy"): "openconfig_routing_policy.RoutingPolicy",
    ("openconfig-routing-policy", "routing-policy"): "openconfig_routing_policy.RoutingPolicy",
    ("http://openconfig.net/yang/telemetry", "telemetry-system"): "openconfig_telemetry.TelemetrySystem",
    ("openconfig-telemetry", "telemetry-system"): "openconfig_telemetry.TelemetrySystem",
    ("http://openconfig.net/yang/terminal-device", "terminal-device"): "openconfig_terminal_device.TerminalDevice",
    ("openconfig-terminal-device", "terminal-device"): "openconfig_terminal_device.TerminalDevice",
    ("http://openconfig.net/yang/optical-transport-line-protection", "aps"): "openconfig_transport_line_protection.Aps",
    ("openconfig-transport-line-protection", "aps"): "openconfig_transport_line_protection.Aps",
    ("http://openconfig.net/yang/vlan", "vlans"): "openconfig_vlan.Vlans",
    ("openconfig-vlan", "vlans"): "openconfig_vlan.Vlans",
}

NAMESPACE_LOOKUP = {
    "cisco-xr-openconfig-interfaces-types": "http://cisco.com/ns/yang/cisco-xr-openconfig-interfaces-types",
    "openconfig-bgp": "http://openconfig.net/yang/bgp",
    "openconfig-bgp-policy": "http://openconfig.net/yang/bgp-policy",
    "openconfig-bgp-types": "http://openconfig.net/yang/bgp-types",
    "openconfig-channel-monitor": "http://openconfig.net/yang/channel-monitor",
    "openconfig-extensions": "http://openconfig.net/yang/openconfig-ext",
    "openconfig-if-aggregate": "http://openconfig.net/yang/interfaces/aggregate",
    "openconfig-if-ethernet": "http://openconfig.net/yang/interfaces/ethernet",
    "openconfig-if-ip": "http://openconfig.net/yang/interfaces/ip",
    "openconfig-interfaces": "http://openconfig.net/yang/interfaces",
    "openconfig-lacp": "http://openconfig.net/yang/lacp",
    "openconfig-local-routing": "http://openconfig.net/yang/local-routing",
    "openconfig-mpls": "http://openconfig.net/yang/mpls",
    "openconfig-mpls-ldp": "http://openconfig.net/yang/ldp",
    "openconfig-mpls-rsvp": "http://openconfig.net/yang/rsvp",
    "openconfig-mpls-sr": "http://openconfig.net/yang/sr",
    "openconfig-mpls-types": "http://openconfig.net/yang/mpls-types",
    "openconfig-optical-amplifier": "http://openconfig.net/yang/optical-amplfier",
    "openconfig-platform": "http://openconfig.net/yang/platform",
    "openconfig-platform-transceiver": "http://openconfig.net/yang/platform/transceiver",
    "openconfig-platform-types": "http://openconfig.net/yang/platform-types",
    "openconfig-policy-types": "http://openconfig.net/yang/policy-types",
    "openconfig-rib-bgp": "http://openconfig.net/yang/rib/bgp",
    "openconfig-rib-bgp-types": "http://openconfig.net/yang/rib/bgp-types",
    "openconfig-routing-policy": "http://openconfig.net/yang/routing-policy",
    "openconfig-telemetry": "http://openconfig.net/yang/telemetry",
    "openconfig-terminal-device": "http://openconfig.net/yang/terminal-device",
    "openconfig-transport-line-common": "http://openconfig.net/yang/transport-line-common",
    "openconfig-transport-line-protection": "http://openconfig.net/yang/optical-transport-line-protection",
    "openconfig-transport-types": "http://openconfig.net/yang/transport-types",
    "openconfig-types": "http://openconfig.net/yang/openconfig-types",
    "openconfig-vlan": "http://openconfig.net/yang/vlan",
    "openconfig-vlan-types": "http://openconfig.net/yang/vlan-types",
}

